血战钢锯岭 (豆瓣)
Description: 血战钢锯岭电影简介和剧情介绍,血战钢锯岭影评、图片、预告片、影讯、论坛、在线购票
Keywords: 血战钢锯岭,Hacksaw Ridge,血战钢锯岭影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.153豆瓣电影Top250

# 血战钢锯岭 Hacksaw Ridge (2016)

导演: 梅尔·吉布森
编剧: 安德鲁·奈特 / 罗伯特·申坎
主演: 安德鲁·加菲尔德 / 萨姆·沃辛顿 / 文斯·沃恩 / 雨果·维文 / 卢克·布雷西 / 泰莉莎·帕尔墨 / 瑞切尔·格里菲斯 / 内森奈尔·布佐里克 / 理查德·劳斯伯格 / 马特·纳夫莱 / 费拉斯·迪拉尼 / 瑞安·柯尔 / 卢克·佩格勒
类型: 剧情 / 传记 / 历史 / 战争
官方网站: www.hacksawridge.movie/
制片国家/地区: 澳大利亚 / 美国
语言: 英语 / 日语
上映日期: 2016-12-08(中国大陆) / 2016-09-04(威尼斯电影节) / 2016-11-04(美国)
片长: 139分钟(中国大陆) / 140分钟(美国)
又名: 钢锯岭 / 钢铁英雄(台) / The Conscientious Objector
IMDb: tt2119532
豆瓣评分
引用
8.7
750909人评价
5星
46.6%
4星
41.5%
3星
10.8%
2星
0.9%
1星
0.2%
好于 97% 战争片
好于 97% 历史片
想看 看过
评价:
推荐

## 血战钢锯岭的剧情简介 · · · · · ·

1945年，第二次世界大战接近尾声，作为邪恶轴心重要成员的日本，其嚣张态势已成强弩之末。是年，决定战局走向的冲绳岛战役拉开序幕，成千上万斗志昂扬的美国大兵被派往冲绳，等待他们的则是敌军重兵防守、凶险异常的钢锯岭。在这群人中间，却有一个不愿拿起武器的军医。他名叫戴斯蒙德·道斯（安德鲁·加菲尔德 Andrew Garfield 饰），来自美国的弗吉尼亚。太平洋爆发之际，瘦弱的戴斯蒙德志愿成为救死扶伤的军医而应征入伍。可因童年和家庭的原因，他始终不愿拿起枪支操练，为此宁愿背上拒服兵役的罪名被送上军事法庭。几经周折，戴斯蒙德最终和战友来到了钢锯岭。枪林弹雨，转瞬之间无数人应声倒地。在信仰和信念的支持下，戴斯蒙德仅凭一己之力拯救了数十条濒死的生命……
本片根据真人真事改编。 ©豆瓣

## 血战钢锯岭的演职员 · · · · · · ( 全部 34 )

- 梅尔·吉布森 导演
- 安德鲁·加菲尔德 饰 Desmond Doss
- 萨姆·沃辛顿 饰 Captain Glover
- 文斯·沃恩 饰 Sgt Howell
- 雨果·维文 饰 Tom Doss
- 卢克·布雷西 饰 Smitty Ryker

## 血战钢锯岭的视频和图片 · · · · · · ( 预告片22 | 视频评论1 · 添加 | 图片894 · 添加 )

## 血战钢锯岭的获奖情况 · · · · · · ( 全部 )

- 第89届奥斯卡金像奖
- 最佳影片(提名)
- 比尔·麦克尼柯 / 大卫·佩穆特

- 第74届金球奖
- 电影类 最佳剧情片(提名)

- 第70届英国电影学院奖
- 电影奖 最佳男主角(提名)
- 安德鲁·加菲尔德

## 喜欢这部电影的人也喜欢 · · · · · ·

  拯救大兵瑞恩

  敦刻尔克

  1917

  黑鹰坠落

  至暗时刻

  穿条纹睡衣的男孩

  辛德勒的名单

  兵临城下

  钢琴家

  决战中途岛

我要写短评

## 血战钢锯岭的短评 · · · · · · ( 全部 177554 条 )

热门 / 最新 / 好友

### 26746 有用 咸菜帮老大 看过 2016-12-01 22:46:33

以我有限的观影经验，优秀的战争片不会美化战场，不会粉饰死亡，不会矮化敌人，不会无视常识，最重要的，不会宣扬战争。这个片子基本都做到了。

### 10281 有用 littledepp 看过 2016-11-28 22:41:13

有个印象很深的片段，首战第一晚他与战友两人坐在战壕里，战友开了一个罐头问他怎么不吃。满脸黑漆漆战灰的道斯笑着摆了摆手说：我不吃肉。多么可敬的人啊，他的信仰无法改变战争，而战争却拿他看似最普通的信仰也无可奈何。

### 4770 有用 桃桃林林 看过 2016-11-25 15:21:45

特别老派的热血直男片，甚至觉得叙事目的性强烈到有些直白。然而，就是好看。前半部分就是压制观众情绪，后面的战争就是帮主角和观者释放，去证明主角。战争场面太硬了，血腥可怕，看到紧张，如炼狱一般。我认同他的那些信仰？胡开尔啊！真正让人激动的，还是见证普通人创造的奇迹，因为这是真的。

### 1085 有用 frozenmoon 看过 2016-12-10 20:38:00

1.战争场面确实不错，子弹穿透头颅以及被炸毁的半个身子。2.感情线的设定有一种豁出去的庸俗。

### 4051 有用 朝暮雪 看过 2016-12-08 02:08:24

救人75命，胜造525级浮屠。

> 更多短评 177554条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 血战钢锯岭的影评 · · · · · · ( 全部 4062 条 )

热门 / 最新 / 好友
无语邻 2016-11-08 10:46:29

## 真实的道哥跟电影不同，他比电影更传奇

看完之后不敢相信，觉得好莱坞主旋律真敢吹啊…… 上网一查，发现这片子居然大多数都是真的，而且历史上的戴斯蒙·道斯这人比电影更神，真英雄，也可以说是真二杆子…… 道哥这人是标准红脖子，农民、拜上帝、估计投票只投共和党。他们家信的是个叫“基督复临安息日会”（Seven... (展开)
6579 306 627回应 收起
nVIDIADriver 2016-11-08 02:32:56

## Saving Private Ryan之后最好的战争片？

这篇影评可能有剧透

和几个美国朋友一起看了Hacksaw Ridge的首映式，而后又再看了一次，可以想象为何此片会获得如此高的观众口碑。 首先说几个点，希望可以帮助打算去看的观众理解剧情： 1，Desmond Doss信奉的小教派在美国非常“另类”（并非正统的基督教），Doss的不被理解也有很大程度源于信... (展开)
2371 145 199回应 收起
大聪 2016-12-07 12:44:46

## 《血战钢锯岭》和真实历史良心拒服兵役事件的出入。

一向以写实，粗暴阳刚著称的导演梅尔吉布森，跨别十年众望所归给我们带来了肾上腺素爆炸的《血战钢锯岭》。 让电影重新离开了大量的绿背景CGI技术。扎扎实实的拍到每一个爆炸，每一条血管被割掉后的喷张。实打实的爆炸和拍摄，最真实的展现二战的人间炼狱。用传统老牌的拍摄手... (展开)
1491 93 248回应 收起
五十米深蓝 2016-12-01 12:16:25

## 看完《血战钢锯岭》你会发现你大爷永远是你大爷

昨天去看了梅尔吉布森的《血战钢锯岭》，有意思的是，我原以为这是部很low的片子，但是！看完之后简直燃爆，不得不说，梅尔吉布森宝刀未老，你大爷永远是你大爷！ 其实每当看到手撕鬼子的某抗日神剧，真的好想对主人公吐槽：先生，您的血浆袋掉了，估计主人公还会诈尸起来说：... (展开)
3615 414 431回应 收起
张腾森 2016-12-09 11:18:20

## 《血战钢锯岭》：一个非主流英雄的诞生

简单粗暴地概括下，《血战钢锯岭》讲的是一个非主流英雄的诞生的故事。在战争渐渐远离公众视野的年代，一部优秀的战争片能让人们重温血与火的灼热，亲临那个枪林弹雨，尸横遍野的悲壮现场，从而前所未有地认识到生命的可贵，更加珍惜来之不易的和平，并反对战争的再次发动。《... (展开)
833 61 75回应 收起
鼠斩车田万齐 2016-11-03 07:04:47

## 逆境下的信仰

信仰是人精神意义上赖以存在的基础，是我们平衡物欲的工具。大多数人选择的是符合社会主流价值的、更容易生存下来的信仰。而如果选择偏离主流的信仰，我们为了捍卫信仰所付出的努力就注定要比其他人更多一些，这条路也会坎坷崎岖。 看完Hacksaw Ridge我想起爸妈以前总叮嘱我的... (展开)
424 24 72回应 收起
木卫二 2016-12-09 14:06:25

## 他打赢了一场救人的战争

首发于微信公众号：movie432，文末有二维码噢~ 当奥巴马历史性地访问广岛，安倍晋三前往珍珠港，二战遗留的历史和道德问题，一步步走向了最后的和解。近几年事关二战的佳片，也开始远离正面战场和著名战役，转而另辟蹊径，像讲述坦克小队作战的《狂怒》，集中营特遣队的《索尔... (展开)
165 27 20回应 收起
Favillae 2016-12-10 05:28:12

## A Hero among Heroes

二刷完觉得可以说点什么了，就来说点什么吧。 直接说，钢锯岭是我今年看到的最喜欢的两部war drama新片之一，另一部是13 Hours，或者也可以说，这是今年我最喜欢的两部新电影。 钢锯岭的主角是战地医护兵（combat medic），Desmond Doss是二战中第一个也是唯一一个以CO（Consci... (展开)
212 10 29回应 收起
doubanzk 2016-12-10 08:46:25

## 《血战钢锯岭》之电影与现实的对比

资料出处：http://www.historyvshollywood.com/reelfaces/hacksaw-ridge/ 1、电影演员与真实人物原型 2、戴斯蒙德·道斯参军的原因 "I felt like it was an honor to serve God and country," Desmond said. "We were fightin' for our religious liberty and freedom.... (展开)
185 12 8回应 收起
猎影娘 2016-12-09 17:25:36

## 何止燃！我特么竟被硬生生捅哭了3次！

我竟然没有一点点防备，被《血战钢锯岭》硬生生捅哭了3次！这是我对这部电影最贴切的评价。对于我这个小老司机的山东爷们，太罕见了！上一次看电影抹眼泪，还是《肖申克的救赎》的最后，安迪在雨中重获自由的那一声呐喊。 在观看之前，祥子对这部电影期望值做了很大保留。首先... (展开)
238 21 28回应 收起

> 更多影评 4062篇

添加新讨论

## 讨论区 · · · · · ·

为什么doss在宿舍里被群殴了，第二天上校问是谁打... | 来自名王字也乃王也 |  | 2022-11-22 05:42:34
主角87岁过世，豆瓣8.7分 | 来自Youngsheldon |  | 2022-11-17 17:56:06
这片子有点虚高 | 来自奥胖 | 3 回应 | 2022-11-16 12:51:55
Doss是不是星期六也上钢锯岭了？ | 来自琦玉老师 | 3 回应 | 2022-10-29 10:51:52
日本人仇美吗？ | 来自木法雨 | 11 回应 | 2022-10-29 10:32:09

> 去这部影片的讨论区（全部334条）

## 关于《血战钢锯岭》的问题 · · · · · · ( 全部128个 )

- 雨果维文的演技值得肯定，个人觉得比主角演的出彩，大家怎么看？ 59人回答
- 请问日本观众会怎么看待类似的“抗日”电影？ 42人回答

> 全部128个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 免费观看
- 腾讯视频 VIP免费观看
- 芒果TV 免费观看
- 优酷视频 免费观看
- 西瓜视频 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- IMDB TOP 250 UPDATE 20221113 (lelechen)

## 谁在看这部电影 · · · · · ·

- deeeeebd
  4分钟前 看过
- 凡尘
  7分钟前 看过
- 千层度
  8分钟前 看过

1380484人看过 / 208308人想看

订阅血战钢锯岭的评论:
feed: rss 2.0